@@ -2,10 +2,10 @@
 
 #
 # Creates distribution files
-# $Id: make-distrib.sh,v 1.18 2004/01/25 22:30:57 vaclavslavik Exp $
+# $Id: make-distrib.sh,v 1.24 2004/09/11 23:12:17 vaclavslavik Exp $
 #
 
-VERSION=1.2.5
+VERSION=1.3.1
 
 #(
 #cd docs_classes
@@ -19,15 +19,10 @@ for i in *.po ; do msgfmt -o `basename $i .po`.mo $i ; done
 )
 
 
-cp NEWS install/news.txt
-cp README install/readme.txt
-cp LICENSE install/license.txt
-crlf -d install/*.txt
-
 find_unix_files()
 {
   (find . -type f -maxdepth 1 ; \
-  find locales src docs extras install -type f) | \
+  find admin locales src docs extras install -type f) | \
     grep -v '/win32-' | \
     grep -v '/CVS' | \
     grep -v '\.\(dsp\|dsw\|chm\|rtf\|iss\|ico\|ncb\|opt\|plg\|rc\)' | \
@@ -39,13 +34,10 @@ find_win32_files()
 {
   echo \
 "docs/chm/*.chm
-src/icons/poedit.ico
-poedit.dsw
-poedit.dsp"
-ls -1 install/{*.txt,*.rtf,*.iss}
+src/icons/appicon/poedit.ico"
+ls -1 install/*.iss
 ls -1 src/*.rc
 ls -1 extras/win32-gettext/*.{exe,dll,COPYING}
-ls -1 extras/win32-db3/*.{h,dll}
 }
 
 
