@@ -12,11 +12,6 @@
 
 */
 
-
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma interface
-#endif
-
 #ifndef _CATALOG_H_
 #define _CATALOG_H_
 
@@ -24,7 +19,7 @@
 #include <wx/dynarray.h>
 #include <wx/encconv.h>
 #include <wx/regex.h>
-
+#include <vector>
 
 class WXDLLEXPORT wxTextFile;
 
@@ -40,8 +35,50 @@ class Catalog
 {
     public:
         /// PO file header information.
-        struct HeaderData
+        class HeaderData
         {
+        public:
+            HeaderData() {}
+            
+            /** Initializes the headers from string that is in msgid "" format
+                (i.e. list of key:value\n entries). */
+            void FromString(const wxString& str);
+
+            /** Converts the header into string representation that can be
+                directly written to .po file as msgid "". */
+            wxString ToString(const wxString& line_delim = wxEmptyString);
+            
+            /// Updates headers list from parsed values entries below
+            void UpdateDict();
+            /// Reverse operation to UpdateDict
+            void ParseDict();
+            
+            /// Returns value of header or empty string if missing.
+            wxString GetHeader(const wxString& key) const;
+
+            /// Returns true if given key is present in the header.
+            bool HasHeader(const wxString& key) const;
+
+            /** Sets header to given value. Overwrites old value if present,
+                appends to the end of header values otherwise. */
+            void SetHeader(const wxString& key, const wxString& value);
+            
+            /// Like SetHeader, but deletes the header if value is empty
+            void SetHeaderNotEmpty(const wxString& key, const wxString& value);
+
+            /// Removes given header entry
+            void DeleteHeader(const wxString& key);
+    
+            struct Entry
+            {
+                wxString Key, Value;
+            };
+            typedef std::vector<Entry> Entries;
+            
+            const Entries& GetAllHeaders() const { return m_entries; }
+
+            // Parsed values:
+            
             wxString Language, Country, Project, CreationDate, 
                      RevisionDate, Translator, TranslatorEmail,
                      Team, TeamEmail, Charset, SourceCodeCharset;
@@ -50,6 +87,11 @@ class Catalog
             wxString BasePath;
 
             wxString Comment;
+
+        protected:
+            Entries m_entries;
+
+            const Entry *Find(const wxString& key) const;
         };
 
         /// Default ctor. Creates empty catalog, you have to call Load.
@@ -82,10 +124,6 @@ class Catalog
 
             Note that \a po_file refers to .po file, .mo file will have same 
             name & location as .po file except for different extension.
-
-            If the header contains data not covered by the PO format, 
-            additional poEdit-specific file with .po.poedit extension is 
-            created.
          */
         bool Save(const wxString& po_file, bool save_mo = true);
 
@@ -131,6 +169,10 @@ class Catalog
         /// Gets catalog header (read-write access).
         HeaderData& Header() { return m_header; }
 
+        /// Returns plural forms count: taken from Plural-Forms header if
+        /// present, 0 otherwise
+        unsigned GetPluralFormsCount() const;
+
         /** Returns status of catalog object: true if ok, false if damaged
             (i.e. constructor or Load failed).
          */
@@ -139,6 +181,14 @@ class Catalog
         /// Appends content of \cat to this catalog.
         void Append(Catalog& cat);
 
+        /** Returns xx_YY ISO code of catalog's language if either the poEdit
+            extensions headers are present or if filename is known and is in
+            the xx[_YY] form, otherwise returns empty string. */
+        wxString GetLocaleCode() const;
+
+        /// Adds entry to the catalog (the catalog will take ownership of
+        /// the object).
+        void AddItem(CatalogData *data);
 
     protected:
         /** Merges the catalog with reference catalog
@@ -166,7 +216,7 @@ class Catalog
             \return true if the merge was OK'ed by the user, false otherwise
          */
         bool ShowMergeSummary(Catalog *refcat);
-            
+ 
     private:
         wxHashTable *m_data;
         CatalogDataArray m_dataArray;
@@ -198,10 +248,13 @@ class CatalogParser
             is false.
          */
         virtual bool OnEntry(const wxString& msgid,
-                             const wxString& msgstr,
+                             const wxString& msgid_plural,
+                             bool has_plural,
+                             const wxArrayString& mtranslations,
                              const wxString& flags,
                              const wxArrayString& references,
                              const wxString& comment,
+                             const wxArrayString& autocomments,
                              unsigned lineNumber) = 0;
 
         /// Textfile being parsed.
@@ -221,23 +274,53 @@ class CatalogData : public wxObject
 {
     public:
         /// Ctor. Initializes the object with original string and translation.
-        CatalogData(const wxString& str, const wxString& translation) 
+        CatalogData(const wxString& str, const wxString& str_plural)
                 : wxObject(), 
-                  m_string(str), 
-                  m_translation(translation), 
+                  m_string(str),
+                  m_plural(str_plural),
+                  m_hasPlural(false),
                   m_references(),
                   m_isFuzzy(false),
-                  m_hasBadTokens(false),
-                  m_isTranslated(!translation.IsEmpty()),
+                  m_isTranslated(false),
                   m_isModified(false),
                   m_isAutomatic(false),
+                  m_validity(Val_Unknown),
                   m_lineNum(0) {}
 
+        CatalogData(const CatalogData& dt)
+                : wxObject(),
+                  m_string(dt.m_string),
+                  m_plural(dt.m_plural),
+                  m_hasPlural(dt.m_hasPlural),
+                  m_translations(dt.m_translations),
+                  m_references(dt.m_references),
+                  m_autocomments(dt.m_autocomments),
+                  m_isFuzzy(dt.m_isFuzzy),
+                  m_isTranslated(dt.m_isTranslated),
+                  m_isModified(dt.m_isModified),
+                  m_isAutomatic(dt.m_isAutomatic),
+                  m_hasBadTokens(dt.m_hasBadTokens),
+                  m_moreFlags(dt.m_moreFlags),
+                  m_comment(dt.m_comment),
+                  m_validity(dt.m_validity),
+                  m_lineNum(dt.m_lineNum),
+                  m_errorString(dt.m_errorString) {}
+
         /// Returns the original string.
         const wxString& GetString() const { return m_string; }
 
-        /// Returns the translation.
-        const wxString& GetTranslation() const { return m_translation; }
+        /// Does this entry have a msgid_plural?
+        const bool HasPlural() const { return m_hasPlural; }
+
+        /// Returns the plural string.
+        const wxString& GetPluralString() const { return m_plural; }
+
+        /// How many translations (plural forms) do we have?
+        size_t GetNumberOfTranslations() const
+            { return m_translations.GetCount(); }
+ 
+        /// Returns the nth-translation.
+        wxString GetTranslation(unsigned n = 0) const;
 
         /// Returns array of all occurences of this string in source code.
         const wxArrayString& GetReferences() const { return m_references; }
@@ -245,6 +328,9 @@ class CatalogData : public wxObject
         /// Returns comment added by the translator to this entry
         const wxString& GetComment() const { return m_comment; }
 
+        /// Returns array of all auto comments.
+        const wxArrayString& GetAutoComments() const { return m_autocomments; }
+
         /// Convenience function: does this entry has a comment?
         const bool HasComment() const { return !m_comment.IsEmpty(); }
 
@@ -262,20 +348,32 @@ class CatalogData : public wxObject
         }
 
         /// Sets the string.
-        void SetString(const wxString& s) { m_string = s; }
+        void SetString(const wxString& s)
+        {
+            m_string = s;
+            m_validity = Val_Unknown;
+        }
+        
+        /// Sets the plural form (if applicable).
+        void SetPluralString(const wxString& p) 
+        { 
+            m_plural = p;
+            m_hasPlural = true;
+        }
 
         /** Sets the translation. Changes "translated" status to true
             if \a t is not empty.
          */
-        void SetTranslation(const wxString& t) 
-        { 
-            m_translation = t; 
-            m_hasBadTokens = !CheckPrintfCorrectness();
-            m_isTranslated = !t.IsEmpty();
-        }
+        void SetTranslation(const wxString& t, unsigned index = 0); 
+
+        /// Sets all translations.
+        void SetTranslations(const wxArrayString& t);
 
         /// Sets the comment.
-        void SetComment(const wxString& c) { m_comment = c; }
+        void SetComment(const wxString& c)
+        {
+            m_comment = c;
+        }
 
         /** Sets gettext flags directly in string format. It may be 
             either empty string or "#, fuzzy", "#, c-format", 
@@ -290,8 +388,6 @@ class CatalogData : public wxObject
         void SetFuzzy(bool fuzzy) { m_isFuzzy = fuzzy; }
         /// Gets value of fuzzy flag.
         bool IsFuzzy() const { return m_isFuzzy; }
-        /// Gets value of badtokens flag.
-        bool HasBadTokens() const { return m_hasBadTokens; }
         /// Sets translated flag.
         void SetTranslated(bool t) { m_isTranslated = t; }
         /// Gets value of translated flag.
@@ -308,22 +404,54 @@ class CatalogData : public wxObject
         void SetLineNumber(unsigned line) { m_lineNum = line; }
         /// Get line number of this entry.
         unsigned GetLineNumber() const { return m_lineNum; }
-            
-    private:
-        /// Checks if %i etc. are correct in the translation (true if yes)
-        bool CheckPrintfCorrectness();
-        bool ValidateTokensString(const wxString& from, const wxString& to);
+
+        /** Returns true if the gettext flags line contains "foo-format"
+            flag when called with "foo" as argument. */
+        bool IsInFormat(const wxString& format);
+        
+        /// Adds new autocomments (#. )
+        void AddAutoComments(const wxString& com)
+        {
+            if (m_autocomments.Index(com) == wxNOT_FOUND) 
+                m_autocomments.Add(com);
+        }
+
+        /// Clears autocomments.
+        void ClearAutoComments()
+        {
+            m_autocomments.Clear();
+        }
+        
+        // Validity (syntax-checking) status of the entry:
+        enum Validity
+        {
+            Val_Unknown = -1,
+            Val_Invalid = 0,
+            Val_Valid = 1
+        };  
+
+        /** Checks if %i etc. are correct in the translation (true if yes).
+            Strings that are not c-format are always correct. */
+        Validity GetValidity() const { return m_validity; }
+        void SetValidity(bool val)
+            { m_validity = val ? Val_Valid : Val_Invalid; }
+
+        void SetErrorString(const wxString& str) { m_errorString = str; }
+        wxString GetErrorString() const { return m_errorString; }
 
     private:
-        static wxRegEx ms_tokenExtraction;
-
-        wxString m_string, m_translation;
-        wxArrayString m_references;
+        wxString m_string, m_plural;
+        bool m_hasPlural;
+        wxArrayString m_translations;
+        
+        wxArrayString m_references, m_autocomments;
         bool m_isFuzzy, m_isTranslated, m_isModified, m_isAutomatic;
         bool m_hasBadTokens;
         wxString m_moreFlags;
         wxString m_comment;
+        Validity m_validity;
         unsigned m_lineNum;
+        wxString m_errorString;
 };
 
 #endif // _CATALOG_H_
