@@ -12,11 +12,6 @@
 
 */
 
-
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 #include <wx/wxprec.h>
 
 #include <wx/wx.h>
@@ -76,6 +71,11 @@ wxLanguage ChooseLanguage()
         { _("(Use default language)"), wxLANGUAGE_DEFAULT },
 
         { _T("Afrikaans"), wxLANGUAGE_AFRIKAANS },
+        { _T("Albanian"), wxLANGUAGE_ALBANIAN },
+        { _T("Amharic"), wxLANGUAGE_AMHARIC },
+        { _T("Bangla"), wxLANGUAGE_BENGALI },
+        { _T("Belarusian"), wxLANGUAGE_BELARUSIAN },
+        { _T("Breton"), wxLANGUAGE_BRETON },
         { _T("Bulgarian"), wxLANGUAGE_BULGARIAN },
         { _T("Catalan"), wxLANGUAGE_CATALAN },
         { _T("Chinese (Traditional)"), wxLANGUAGE_CHINESE_TRADITIONAL },
@@ -86,11 +86,13 @@ wxLanguage ChooseLanguage()
         { _T("Dutch"), wxLANGUAGE_DUTCH },
         { _T("English"), wxLANGUAGE_ENGLISH },
         { _T("Estonian"), wxLANGUAGE_ESTONIAN },
+        { _T("Esperanto"), wxLANGUAGE_ESPERANTO },
         { _T("Farsi"), wxLANGUAGE_FARSI },
         { _T("French"), wxLANGUAGE_FRENCH },
         { _T("Georgian"), wxLANGUAGE_GEORGIAN },
         { _T("German"), wxLANGUAGE_GERMAN },
         { _T("Greek"), wxLANGUAGE_GREEK },
+        { _T("Hindi"), wxLANGUAGE_HINDI },
         { _T("Hungarian"), wxLANGUAGE_HUNGARIAN },
         { _T("Icelandic"), wxLANGUAGE_ICELANDIC },
         { _T("Italian"), wxLANGUAGE_ITALIAN },
@@ -99,10 +101,11 @@ wxLanguage ChooseLanguage()
         { _T("Lithuanian"), wxLANGUAGE_LITHUANIAN },
         { _T("Mongolian"), wxLANGUAGE_MONGOLIAN },
         { _T("Norwegian Nynorsk"), wxLANGUAGE_NORWEGIAN_NYNORSK },
-        { _T("Norwegian Bokml"), wxLANGUAGE_NORWEGIAN_BOKMAL },
+        { _T("Norwegian Bokmal"), wxLANGUAGE_NORWEGIAN_BOKMAL },
         { _T("Polish"), wxLANGUAGE_POLISH },
         { _T("Portuguese"), wxLANGUAGE_PORTUGUESE },
         { _T("Portuguese (Brazilian)"), wxLANGUAGE_PORTUGUESE_BRAZILIAN },
+        { _T("Punjabi"), wxLANGUAGE_PUNJABI },
         { _T("Romanian"), wxLANGUAGE_ROMANIAN },
         { _T("Russian"), wxLANGUAGE_RUSSIAN },
         { _T("Serbian"), wxLANGUAGE_SERBIAN },
