@@ -12,12 +12,8 @@
 
 */
 
-
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 #include <wx/string.h>
+#include <wx/filefn.h> // workaround for wx-2.5.1 bug
 #include <wx/config.h>
 #include <wx/dir.h>
 
