@@ -13,10 +13,6 @@
 */
 
 
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 #include <wx/wxprec.h>
 
 #include <wx/wx.h>
@@ -34,6 +30,7 @@
 #include "prefsdlg.h"
 #include "parser.h"
 #include "chooselang.h"
+#include "icons.h"
 
 
 IMPLEMENT_APP(poEditApp);
@@ -62,7 +59,7 @@ wxString poEditApp::GetAppPath() const
 
 wxString poEditApp::GetAppVersion() const
 {
-    return _T("1.2.5");
+    return _T("1.3.1");
 }
 
 
@@ -137,6 +134,11 @@ bool poEditApp::OnInit()
     
     SetDefaultCfg(wxConfig::Get());
 
+    wxArtProvider::PushProvider(new wxPoeditStdArtProvider);
+#ifdef HAS_THEMES_SUPPORT
+    wxArtProvider::PushProvider(new wxPoeditThemeArtProvider);
+#endif
+
     if (wxConfig::Get()->Read(_T("translator_name"), _T("nothing")) == _T("nothing"))
     {
         wxMessageBox(_("This is first time you run poEdit.\nPlease fill in your name and e-mail address.\n(This information is used only in catalogs headers)"), _("Setup"),
