@@ -13,10 +13,6 @@
 */
 
 
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma implementation
-#endif
-
 #ifndef _EDAPP_H_
 #define _EDAPP_H_
 
@@ -34,6 +30,7 @@ class poEditApp : public wxApp
             configuration entries to default values if they were missing.
          */
         bool OnInit();
+
         /** Gets application's path. This path is used when looking for 
             resources.zip and help files, both of them can be found
             in {appPath}/share/poedit. Looks in registry under Windows
