@@ -8,15 +8,10 @@
     
       Editor frame
     
-      (c) Vaclav Slavik, 2000
+      (c) Vaclav Slavik, 2000-2004
 
 */
 
-
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma interface
-#endif
-
 #ifndef _EDFRAME_H_
 #define _EDFRAME_H_
 
@@ -24,15 +19,20 @@
   #define CAN_MODIFY_DEFAULT_FONT
 #endif
 
+#include <list>
 
 #include <wx/frame.h>
 #include <wx/docview.h>
 #include <wx/list.h>
+#include <wx/process.h>
+
 class WXDLLEXPORT wxListCtrl;
 class WXDLLEXPORT wxListEvent;
 class WXDLLEXPORT wxSplitterWindow;
 class WXDLLEXPORT wxTextCtrl;
 class WXDLLEXPORT wxGauge;
+class WXDLLEXPORT wxNotebook;
+class WXDLLEXPORT wxStaticText;
 
 #ifdef __WXMSW__
 #include <wx/msw/helpchm.h>
@@ -41,6 +41,7 @@ class WXDLLEXPORT wxGauge;
 #endif
 
 #include "catalog.h"
+#include "gexecute.h"
 
 class poEditListCtrl;
 class TranslationMemory;
@@ -124,6 +125,9 @@ class poEditFrame : public wxFrame
         TranslationMemory *GetTransMem();
 #endif
 
+        // (Re)initializes spellchecker, if needed
+        void InitSpellchecker();
+        
         void AddItemsToList(const Catalog& catalog,
                             poEditListCtrl *list, size_t& pos,
                             bool (*filter)(const CatalogData& d),
@@ -147,6 +151,7 @@ class poEditFrame : public wxFrame
         void OnUpdate(wxCommandEvent& event);
         void OnListSel(wxListEvent& event);
         void OnListDesel(wxListEvent& event);
+        void OnListActivated(wxListEvent& event);
         void OnCloseWindow(wxCloseEvent& event);
         void OnReference(wxCommandEvent& event);
         void OnReferencesMenu(wxCommandEvent& event);
@@ -171,12 +176,31 @@ class poEditFrame : public wxFrame
         
         void OnExport(wxCommandEvent& event);
         bool ExportCatalog(const wxString& filename);
+
+        void OnIdle(wxIdleEvent& event);
+        void OnEndProcess(wxProcessEvent& event);
+
+        void BeginItemValidation();
+        void EndItemValidation();
         
         void UpdateDisplayCommentWin();
+
+        void ShowPluralFormUI(bool show = true);
+
+        void RecreatePluralTextCtrls();
     
         DECLARE_EVENT_TABLE()
 
     private:
+        struct ValidationProcessData : public GettextProcessData
+        {
+            wxString tmp1, tmp2;
+        };
+            
+        int m_itemBeingValidated;
+        std::list<int> m_itemsToValidate;
+        ValidationProcessData m_validationProcess;
+        
         bool m_commentWindowEditable;
         Catalog *m_catalog;
         wxString m_fileName;
@@ -197,8 +221,11 @@ class poEditFrame : public wxFrame
         wxPanel *m_bottomLeftPanel;
         wxSplitterWindow *m_splitter, *m_bottomSplitter;
         poEditListCtrl *m_list;
-        wxTextCtrl *m_textOrig, *m_textTrans, *m_textComment;
+        wxTextCtrl *m_textOrig, *m_textOrigPlural, *m_textTrans, *m_textComment;
+        std::vector<wxTextCtrl*> m_textTransPlural;
+        wxNotebook *m_pluralNotebook;
         wxGauge *m_statusGauge;
+        wxStaticText *m_labelSingular, *m_labelPlural;
 #ifdef CAN_MODIFY_DEFAULT_FONT
         wxFont m_boldGuiFont;
 #endif
@@ -210,7 +237,7 @@ class poEditFrame : public wxFrame
         bool m_displayCommentWin;
         int m_sel, m_selItem;
         wxFileHistory m_history;
-        wxString m_edittedTextOrig;
+        std::vector<wxString> m_edittedTextOrig;
         bool m_edittedTextFuzzyChanged;
         
         friend class ListHandler;
