@@ -9,15 +9,10 @@
     
       (c) Christophe Hermier, 2003
 
-      $Id: export_html.cpp,v 1.2 2004/01/25 20:29:21 vaclavslavik Exp $
+      $Id: export_html.cpp,v 1.3 2004/06/06 14:10:59 vaclavslavik Exp $
 
 */
 
-
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 #include <wx/intl.h>
 #include <wx/colour.h>
 #include <wx/utils.h>
