@@ -8,15 +8,10 @@
     
       Shows part of file around specified line
     
-      (c) Vaclav Slavik, 2000
+      (c) Vaclav Slavik, 2000, 2004
 
 */
 
-
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 #include <wx/wxprec.h>
 
 #include "fileviewer.h"
