@@ -8,15 +8,10 @@
     
       Gettext execution code
     
-      (c) Vaclav Slavik, 2000-2003
+      (c) Vaclav Slavik, 2000-2004
  
 */
 
-
-#ifdef __GNUG__
-#pragma implementation
-#endif 
-
 #include <wx/wxprec.h>
 
 #include <wx/utils.h> 
@@ -26,21 +21,13 @@
 #include <wx/string.h> 
 #include <wx/intl.h>
 
+#include "gexecute.h"
 
-struct MyProcessData
-{
-        bool Running;
-        int ExitCode;
-        wxArrayString Stderr;
-        wxArrayString Stdout;
-};
-
-
-
-class MyPipedProcess : public wxProcess
+class GettextProcess : public wxProcess
 {
     public:
-        MyPipedProcess(MyProcessData *data) : wxProcess(), m_data(data)
+        GettextProcess(GettextProcessData *data, wxEvtHandler *parent) 
+            : wxProcess(parent), m_data(data)
         {
             m_data->Running = true;
             m_data->Stderr.Empty();
@@ -80,11 +67,10 @@ class MyPipedProcess : public wxProcess
         }
 
     private:
-        MyProcessData *m_data;
+        GettextProcessData *m_data;
 };
 
 
-#ifdef __UNIX__
 // we have to do this because otherwise xgettext might
 // speak in native language, not English, and we cannot parse
 // it correctly (not yet)
@@ -95,11 +81,13 @@ class TempLocaleSwitcher
         {
             wxGetEnv(_T("LC_ALL"), &m_all);
             wxGetEnv(_T("LC_MESSAGES"), &m_messages);
-            wxGetEnv(_T("LC_LANG"), &m_lang);
+            wxGetEnv(_T("LANG"), &m_lang);
+            wxGetEnv(_T("LANGUAGE"), &m_language);
 
             wxSetEnv(_T("LC_ALL"), locale);
             wxSetEnv(_T("LC_MESSAGES"), locale);
             wxSetEnv(_T("LANG"), locale);
+            wxSetEnv(_T("LANGUAGE"), locale);
         }
         
         ~TempLocaleSwitcher()
@@ -107,25 +95,23 @@ class TempLocaleSwitcher
             wxSetEnv(_T("LC_ALL"), m_all);
             wxSetEnv(_T("LC_MESSAGES"), m_messages);
             wxSetEnv(_T("LANG"), m_lang);
+            wxSetEnv(_T("LANGUAGE"), m_language);
         }
         
     private:
-        wxString m_all, m_messages, m_lang;
+        wxString m_all, m_messages, m_lang, m_language;
 };
-#endif
 
 
-bool ExecuteGettext(const wxString& cmdline)
+bool ExecuteGettext(const wxString& cmdline, wxString *stderrOutput)
 {
-#ifdef __UNIX__
-    TempLocaleSwitcher localeSwitcher(_T("en"));
-#endif
+    TempLocaleSwitcher localeSwitcher(_T("C"));
 
     size_t i;
-    MyProcessData pdata;
-    MyPipedProcess *process;
+    GettextProcessData pdata;
+    GettextProcess *process;
 
-    process = new MyPipedProcess(&pdata);
+    process = new GettextProcess(&pdata, NULL);
     int pid = wxExecute(cmdline, false, process);
 
     if (pid == 0)
@@ -154,9 +140,32 @@ bool ExecuteGettext(const wxString& cmdline)
             if (dummy.empty() || dummy == _T(" done")) continue;
             //msgmerge outputs *progress* to stderr, damn it!
         }
-        wxLogError(_T("%s"), pdata.Stderr[i].c_str());
+        if (stderrOutput)
+            *stderrOutput += pdata.Stderr[i] + _T("\n");
+        else
+            wxLogError(_T("%s"), pdata.Stderr[i].c_str());
     }
     
     return pdata.ExitCode == 0;
 }
 
+
+bool ExecuteGettextNonblocking(const wxString& cmdline,
+                               GettextProcessData *data,
+                               wxEvtHandler *parent)
+{
+    TempLocaleSwitcher localeSwitcher(_T("C"));
+
+    GettextProcess *process;
+
+    process = new GettextProcess(data, parent);
+    int pid = wxExecute(cmdline, false, process);
+
+    if (pid == 0)
+    {
+        wxLogError(_("Cannot execute program: ") + cmdline.BeforeFirst(_T(' ')));
+        return false;
+    }
+
+    return true;
+}
