@@ -16,7 +16,7 @@ LanguageStruct isoLanguages[] =
     {_T("az"), _T("Azerbaijani")},
 
     {_T("ba"), _T("Bashkir")},
-    {_T("be"), _T("Byelorussian")},
+    {_T("be"), _T("Belarusian")},
     {_T("bg"), _T("Bulgarian")},
     {_T("bh"), _T("Bihari")},
     {_T("bi"), _T("Bislama")},
@@ -116,7 +116,7 @@ LanguageStruct isoLanguages[] =
     {_T("ng"), _T("Ndonga")},
     {_T("nl"), _T("Dutch")},
     {_T("nn"), _T("Norwegian Nynorsk")},
-    {_T("nb"), _T("Norwegian Bokml")},
+    {_T("nb"), _T("Norwegian Bokmal")},
     {_T("nr"), _T("Ndebele, South")},
     {_T("nv"), _T("Navajo")},
     {_T("ny"), _T("Chichewa; Nyanja")},
@@ -183,6 +183,7 @@ LanguageStruct isoLanguages[] =
     {_T("vi"), _T("Vietnamese")},
     {_T("vo"), _T("Volapuk")},
 
+    {_T("wa"), _T("Walloon")},
     {_T("wo"), _T("Wolof")},
 
     {_T("xh"), _T("Xhosa")},
@@ -447,7 +448,7 @@ LanguageStruct isoCountries[] =
 };
 
 
-static const wxChar *DoLookup(const wxChar *lng, LanguageStruct *a)
+static const wxChar *DoLookupByLang(const wxChar *lng, LanguageStruct *a)
 {
     if (lng == NULL)
         return NULL;
@@ -459,12 +460,34 @@ static const wxChar *DoLookup(const wxChar *lng, LanguageStruct *a)
     return NULL;
 }
 
+static const wxChar *DoLookupByIso(const wxChar *iso, LanguageStruct *a)
+{
+    if (iso == NULL)
+        return NULL;
+    for (size_t i = 0; a[i].iso != NULL; i++)
+    {
+        if (wxStricmp(a[i].iso, iso) == 0)
+            return a[i].lang;
+    }
+    return NULL;
+}
+
 const wxChar *LookupLanguageCode(const wxChar *language)
 {
-    return DoLookup(language, isoLanguages);
+    return DoLookupByLang(language, isoLanguages);
 }
 
 const wxChar *LookupCountryCode(const wxChar *country)
 {
-    return DoLookup(country, isoCountries);
+    return DoLookupByLang(country, isoCountries);
+}
+
+bool IsKnownLanguageCode(const wxChar *code)
+{
+    return DoLookupByIso(code, isoLanguages) != NULL;
+}
+
+bool IsKnownCountryCode(const wxChar *code)
+{
+    return DoLookupByIso(code, isoCountries) != NULL;
 }
