@@ -8,15 +8,10 @@
     
       Catalogs manager
     
-      (c) Vaclav Slavik, 2001
+      (c) Vaclav Slavik, 2001,2004
 
 */
 
-
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 #include <wx/wxprec.h>
 
 #include <wx/imaglist.h>
@@ -36,14 +31,12 @@
 #include <wx/imaglist.h>
 #include <wx/dirdlg.h>
 #include <wx/log.h>
+#include <wx/artprov.h>
 
 #include "catalog.h"
 #include "edframe.h"
 #include "manager.h"
-
-#ifdef __UNIX__
-#include "icons/poedit.xpm"
-#endif
+#include "prefsdlg.h"
 
 ManagerFrame *ManagerFrame::ms_instance = NULL;
 
@@ -57,10 +50,6 @@ ManagerFrame *ManagerFrame::ms_instance = NULL;
     return ms_instance;
 }
 
-#include "cat_ok.xpm"
-#include "cat_mid.xpm"
-#include "cat_no.xpm"
-
 ManagerFrame::ManagerFrame() :
     wxFrame(NULL, -1, _("poEdit - Catalogs manager"), wxPoint(
                                  wxConfig::Get()->Read(_T("manager_x"), -1),
@@ -70,11 +59,16 @@ ManagerFrame::ManagerFrame() :
                                  wxConfig::Get()->Read(_T("manager_h"), 300)),
                              wxDEFAULT_FRAME_STYLE | wxNO_FULL_REPAINT_ON_RESIZE)
 {
+#ifdef __UNIX__
+    SetIcon(wxArtProvider::GetIcon(_T("poedit-appicon")));
+#else
     SetIcon(wxICON(appicon));
+#endif
     
     ms_instance = this;
 
     SetToolBar(wxXmlResource::Get()->LoadToolBar(this, _T("manager_toolbar")));
+    SetMenuBar(wxXmlResource::Get()->LoadMenuBar(_T("manager_menu")));
     
     wxPanel *panel = wxXmlResource::Get()->LoadPanel(this, _T("manager_panel"));
     
@@ -82,9 +76,9 @@ ManagerFrame::ManagerFrame() :
     m_listCat = XRCCTRL(*panel, "prj_files", wxListCtrl);
     
     wxImageList *list = new wxImageList(16, 16);
-    list->Add(wxBitmap(cat_no_xpm));
-    list->Add(wxBitmap(cat_mid_xpm));
-    list->Add(wxBitmap(cat_ok_xpm));
+    list->Add(wxArtProvider::GetBitmap(_T("poedit-status-cat-no")));
+    list->Add(wxArtProvider::GetBitmap(_T("poedit-status-cat-mid")));
+    list->Add(wxArtProvider::GetBitmap(_T("poedit-status-cat-ok")));
     m_listCat->AssignImageList(list, wxIMAGE_LIST_SMALL);
 
     m_curPrj = -1;
@@ -336,6 +330,8 @@ BEGIN_EVENT_TABLE(ManagerFrame, wxFrame)
    EVT_MENU                 (XRCID("prj_update"), ManagerFrame::OnUpdateProject)
    EVT_LISTBOX              (XRCID("prj_list"),   ManagerFrame::OnSelectProject)
    EVT_LIST_ITEM_ACTIVATED  (XRCID("prj_files"),  ManagerFrame::OnOpenCatalog)
+   EVT_MENU                 (XRCID("menu_quit"),  ManagerFrame::OnQuit)
+   EVT_MENU                 (XRCID("menu_preferences"), ManagerFrame::OnPreferences)
 END_EVENT_TABLE()
 
 
@@ -428,3 +424,20 @@ void ManagerFrame::OnOpenCatalog(wxListEvent& event)
 {
     poEditFrame::Create(m_catalogs[event.GetIndex()])->Raise();
 }
+
+
+void ManagerFrame::OnPreferences(wxCommandEvent&)
+{
+    PreferencesDialog dlg(this);
+    
+    dlg.TransferTo(wxConfig::Get());
+    if (dlg.ShowModal() == wxID_OK)
+    {
+        dlg.TransferFrom(wxConfig::Get());
+    }
+}
+
+void ManagerFrame::OnQuit(wxCommandEvent&)
+{
+    Close(true);
+}
