@@ -8,15 +8,10 @@
     
       Catalogs manager frame
     
-      (c) Vaclav Slavik, 2001
+      (c) Vaclav Slavik, 2001,2004
 
 */
 
-
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma interface
-#endif
-
 #ifndef _MANAGER_H_
 #define _MANAGER_H_
 
@@ -70,6 +65,8 @@ class ManagerFrame : public wxFrame
         void OnUpdateProject(wxCommandEvent& event);
         void OnSelectProject(wxCommandEvent& event);
         void OnOpenCatalog(wxListEvent& event);
+        void OnPreferences(wxCommandEvent& event);
+        void OnQuit(wxCommandEvent& event);
 
         wxListCtrl *m_listCat;
         wxListBox  *m_listPrj;      
