@@ -13,10 +13,6 @@
 */
 
 
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 #include <wx/wxprec.h>
 
 #include <wx/wfstream.h>
