@@ -12,11 +12,6 @@
 
 */
 
-
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma interface
-#endif
-
 #ifndef _SETTINGSDLG_H_
 #define _SETTINGSDLG_H_
 
@@ -44,6 +39,7 @@ class SettingsDialog : public wxDialog
     private:
         wxTextCtrl *m_team, *m_teamEmail, *m_project;            
         wxComboBox *m_charset, *m_language, *m_country, *m_sourceCodeCharset;
+        wxTextCtrl *m_pluralForms;
         wxTextCtrl *m_basePath;
         wxEditableListBox *m_paths, *m_keywords;
 };
